@@ -98,7 +98,8 @@ sub make_optional_modules_tests {
 	or die "Can not create $dir: $!\n";
     opendir my $dh, 't'
 	or die "Can not access t/: $!\n";
-    while ( readdir $dh ) {
+    local $_ = undef;
+    while ( defined( $_ = readdir $dh ) ) {
 	m/ \A [.] /smx
 	    and next;
 	m/ [.] t \z /smx
@@ -237,7 +238,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2014-2017 by Thomas R. Wyant, III
+Copyright (C) 2014-2018 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
